const point = (lon, lat) => ({
	type: 'Point',
	coordinates: [lon, lat],
});

const feature = (geometry, props = {}) => ({
	type: 'Feature',
	properties: props,
	geometry: geometry,
});

const wienFlughafen = {
	type: 'stop',
	id: '8100353',
	name: 'Flughafen Wien Bahnhof',
	location: {
		type: 'location',
		id: '8100353',
		latitude: 48.121163,
		longitude: 16.562418,
	},
	products: {
		nationalExpress: true,
		national: false,
		interregional: true,
		regional: true,
		suburban: true,
		bus: false,
		ferry: false,
		subway: false,
		tram: false,
		onCall: false,
	},
};

const salzburgHbf = {
	type: 'stop',
	id: '8100002',
	name: 'Salzburg Hbf',
	location: {
		type: 'location',
		id: '8100002',
		latitude: 47.812851,
		longitude: 13.045604,
	},
	products: {
		nationalExpress: true,
		national: true,
		interregional: true,
		regional: true,
		suburban: true,
		bus: false,
		ferry: false,
		subway: false,
		tram: false,
		onCall: false,
	},
};

const öbbWestbahnTickets = {
	type: 'hint',
	code: 'O5',
	text: 'Hinweis: Gegenseitige Anerkennung von ÖBB- und WESTbahn-Tickets (Wien Hbf - Salzburg Hbf)',
};

const corona = {
	id: '483655',
	type: 'warning',
	summary: 'Fahrplanänderung ab 20.04.2020',
	text: 'Wegen der aktuellen Corona-Situation beachten Sie bitte den geänderten Fahrplan des Fernverkehrs zwischen Wien und Salzburg. Vor der Fahrt gekaufte Tickets der ÖBB und WESTbahn werden weiterhin gegenseitig in den <b>Fernverkehrszügen</b> (RJ, RJX, ICE, WESTbahn) und für<b> Abschnitte der Nahverkehrszüge</b> S80 (Wien Hütteldorf - Wien Meidling) und CJX (Wien Westbahnhof - Amstetten) anerkannt. Bitte beachten Sie, dass die Anerkennung von zuggebundenen Tickets (z.B. Sparschiene) nicht möglich ist. Informationen dazu erhalten Sie im Internet auf <a href="https://www.westbahn.at">www.westbahn.at</a>, <a href= "https://kundeninformation-pv.oebb.at/dam/verkehrsauskunft/extern/2020/2020_04/OBB-Fahrplan_Weststrecke_Westbahn_A4q_200423b.pdf"> Fahrplan</a> und <a href="https://www.oebb.at/de/neuigkeiten/einschraenkungen-im-bahnverkehr#faqs"> unter den Neuigkeiten der ÖBB</a>.\n',
	icon: {type: 'HIM5', title: null},
	priority: 100,
	category: 5,
	products: {
		nationalExpress: true,
		national: true,
		interregional: true,
		regional: true,
		suburban: true,
		bus: true,
		ferry: true,
		subway: true,
		tram: true,
		onCall: true,
	},
	edges: [{
		icoCrd: {x: 14768356, y: 48156724, type: 'WGS84'},
		icon: null,
		fromLocation: null,
		toLocation: null,
	}],
	validFrom: '2020-05-15T00:00:00+02:00',
	validUntil: '2020-06-30T23:59:00+02:00',
	modified: '2020-05-28T13:48:14+02:00',
};

const oebbTrip = {
	id: '2|#VN#0#ST#1591790769#PI#0#ZI#398470#TA#0#DA#110620#1S#8100353#1T#1633#LS#8100002#LT#1948#PU#81#RT#1#CA#RJ#ZE#742#ZB#RJ 742  #',
	origin: wienFlughafen,
	destination: salzburgHbf,
	arrival: '2020-06-11T19:48:00+02:00',
	plannedArrival: '2020-06-11T19:48:00+02:00',
	arrivalDelay: null,
	arrivalPrognosisType: 'prognosed',
	departure: '2020-06-11T16:33:00+02:00',
	plannedDeparture: '2020-06-11T16:33:00+02:00',
	departureDelay: null,
	departurePrognosisType: 'prognosed',
	line: {
		type: 'line',
		id: 'rj-742',
		fahrtNr: '742',
		name: 'RJ 742',
		public: true,
		adminCode: '81____',
		productName: 'RJ',
		mode: 'train',
		product: 'nationalExpress',
		operator: {type: 'operator', id: 'nahreisezug', name: 'Nahreisezug'},
	},
	direction: 'Salzburg Hbf',
	arrivalPlatform: '6A-C',
	plannedArrivalPlatform: '4A-C',
	departurePlatform: '2',
	plannedDeparturePlatform: '2',
	stopovers: [
		{
			stop: wienFlughafen,
			arrival: null,
			plannedArrival: null,
			arrivalDelay: null,
			arrivalPlatform: null,
			plannedArrivalPlatform: null,
			arrivalPrognosisType: null,
			departure: '2020-06-11T16:33:00+02:00',
			plannedDeparture: '2020-06-11T16:33:00+02:00',
			departureDelay: null,
			departurePlatform: '2',
			plannedDeparturePlatform: '2',
			departurePrognosisType: 'prognosed',
		},
		{
			stop: {
				type: 'stop',
				id: '8103000',
				name: 'Wien Hbf',
				location: {
					type: 'location',
					id: '8103000',
					latitude: 48.184564,
					longitude: 16.378526,
				},
				products: {
					nationalExpress: true,
					national: true,
					interregional: true,
					regional: true,
					suburban: true,
					bus: false,
					ferry: false,
					subway: false,
					tram: false,
					onCall: false,
				},
			},
			arrival: '2020-06-11T16:48:00+02:00',
			plannedArrival: '2020-06-11T16:48:00+02:00',
			arrivalDelay: null,
			arrivalPlatform: '8A-C',
			plannedArrivalPlatform: '8A-B',
			arrivalPrognosisType: 'prognosed',
			departure: '2020-06-11T16:55:00+02:00',
			plannedDeparture: '2020-06-11T16:55:00+02:00',
			departureDelay: null,
			departurePlatform: '8A-C',
			plannedDeparturePlatform: '8A-B',
			departurePrognosisType: 'prognosed',
			remarks: [
				öbbWestbahnTickets,
				corona,
			],
		},
		{
			stop: {
				type: 'stop',
				id: '8100514',
				name: 'Wien Meidling Bahnhof',
				location: {
					type: 'location',
					id: '8100514',
					latitude: 48.174585,
					longitude: 16.333733,
				},
				products: {
					nationalExpress: true,
					national: true,
					interregional: true,
					regional: true,
					suburban: true,
					bus: false,
					ferry: false,
					subway: false,
					tram: false,
					onCall: false,
				},
			},
			arrival: '2020-06-11T17:00:00+02:00',
			plannedArrival: '2020-06-11T17:00:00+02:00',
			arrivalDelay: null,
			arrivalPlatform: '5',
			plannedArrivalPlatform: '5',
			arrivalPrognosisType: 'prognosed',
			departure: '2020-06-11T17:02:00+02:00',
			plannedDeparture: '2020-06-11T17:02:00+02:00',
			departureDelay: null,
			departurePlatform: '5',
			plannedDeparturePlatform: '5',
			departurePrognosisType: 'prognosed',
			remarks: [
				öbbWestbahnTickets,
				corona,
			],
		},
		{
			stop: {
				type: 'stop',
				id: '8102059',
				name: 'Tullnerfeld Bahnhof',
				location: {
					type: 'location',
					id: '8102059',
					latitude: 48.295167,
					longitude: 15.996538,
				},
				products: {
					nationalExpress: true,
					national: true,
					interregional: true,
					regional: true,
					suburban: true,
					bus: false,
					ferry: false,
					subway: false,
					tram: false,
					onCall: false,
				},
			},
			arrival: '2020-06-11T17:15:00+02:00',
			plannedArrival: '2020-06-11T17:15:00+02:00',
			arrivalDelay: null,
			arrivalPlatform: '3',
			plannedArrivalPlatform: '3',
			arrivalPrognosisType: 'prognosed',
			departure: '2020-06-11T17:16:00+02:00',
			plannedDeparture: '2020-06-11T17:16:00+02:00',
			departureDelay: null,
			departurePlatform: '3',
			plannedDeparturePlatform: '3',
			departurePrognosisType: 'prognosed',
			remarks: [
				öbbWestbahnTickets,
				corona,
			],
		},
		{
			stop: {
				type: 'stop',
				id: '8100008',
				name: 'St.Pölten Hbf',
				location: {
					type: 'location',
					id: '8100008',
					latitude: 48.20825,
					longitude: 15.624681,
				},
				products: {
					nationalExpress: true,
					national: true,
					interregional: true,
					regional: true,
					suburban: true,
					bus: false,
					ferry: false,
					subway: false,
					tram: false,
					onCall: false,
				},
			},
			arrival: '2020-06-11T17:28:00+02:00',
			plannedArrival: '2020-06-11T17:28:00+02:00',
			arrivalDelay: null,
			arrivalPlatform: '5',
			plannedArrivalPlatform: '5',
			arrivalPrognosisType: 'prognosed',
			departure: '2020-06-11T17:30:00+02:00',
			plannedDeparture: '2020-06-11T17:30:00+02:00',
			departureDelay: null,
			departurePlatform: '5',
			plannedDeparturePlatform: '5',
			departurePrognosisType: 'prognosed',
			remarks: [
				öbbWestbahnTickets,
				corona,
			],
		},
		{
			stop: {
				type: 'stop',
				id: '8100012',
				name: 'Amstetten NÖ Bahnhof',
				location: {
					type: 'location',
					id: '8100012',
					latitude: 48.121477,
					longitude: 14.878199,
				},
				products: {
					nationalExpress: true,
					national: false,
					interregional: true,
					regional: true,
					suburban: false,
					bus: false,
					ferry: false,
					subway: false,
					tram: false,
					onCall: false,
				},
			},
			arrival: '2020-06-11T18:00:00+02:00',
			plannedArrival: '2020-06-11T18:00:00+02:00',
			arrivalDelay: null,
			arrivalPlatform: '2',
			plannedArrivalPlatform: '2',
			arrivalPrognosisType: 'prognosed',
			departure: '2020-06-11T18:02:00+02:00',
			plannedDeparture: '2020-06-11T18:02:00+02:00',
			departureDelay: null,
			departurePlatform: '2',
			plannedDeparturePlatform: '2',
			departurePrognosisType: 'prognosed',
			remarks: [
				öbbWestbahnTickets,
				corona,
			],
		},
		{
			stop: {
				type: 'stop',
				id: '8100009',
				name: 'St.Valentin Bahnhof',
				location: {
					type: 'location',
					id: '8100009',
					latitude: 48.17873,
					longitude: 14.522083,
				},
				products: {
					nationalExpress: true,
					national: false,
					interregional: true,
					regional: true,
					suburban: true,
					bus: false,
					ferry: false,
					subway: false,
					tram: false,
					onCall: false,
				},
			},
			arrival: '2020-06-11T18:16:00+02:00',
			plannedArrival: '2020-06-11T18:16:00+02:00',
			arrivalDelay: null,
			arrivalPlatform: '1A-G',
			plannedArrivalPlatform: '1A-F',
			arrivalPrognosisType: 'prognosed',
			departure: '2020-06-11T18:17:00+02:00',
			plannedDeparture: '2020-06-11T18:17:00+02:00',
			departureDelay: null,
			departurePlatform: '1A-G',
			plannedDeparturePlatform: '1A-F',
			departurePrognosisType: 'prognosed',
			remarks: [
				öbbWestbahnTickets,
				corona,
			],
		},
		{
			stop: {
				type: 'stop',
				id: '8100013',
				name: 'Linz/Donau Hbf',
				location: {
					type: 'location',
					id: '8100013',
					latitude: 48.29016,
					longitude: 14.291941,
				},
				products: {
					nationalExpress: true,
					national: true,
					interregional: true,
					regional: true,
					suburban: true,
					bus: false,
					ferry: false,
					subway: false,
					tram: false,
					onCall: false,
				},
			},
			arrival: '2020-06-11T18:30:00+02:00',
			plannedArrival: '2020-06-11T18:30:00+02:00',
			arrivalDelay: null,
			arrivalPlatform: '6A-F',
			plannedArrivalPlatform: '6A-F',
			arrivalPrognosisType: 'prognosed',
			departure: '2020-06-11T18:32:00+02:00',
			plannedDeparture: '2020-06-11T18:32:00+02:00',
			departureDelay: null,
			departurePlatform: '6A-F',
			plannedDeparturePlatform: '6A-F',
			departurePrognosisType: 'prognosed',
			remarks: [
				öbbWestbahnTickets,
				corona,
			],
		},
		{
			stop: {
				type: 'stop',
				id: '8100014',
				name: 'Wels Hbf',
				location: {
					type: 'location',
					id: '8100014',
					latitude: 48.166208,
					longitude: 14.027271,
				},
				products: {
					nationalExpress: true,
					national: true,
					interregional: true,
					regional: true,
					suburban: true,
					bus: false,
					ferry: false,
					subway: false,
					tram: false,
					onCall: false,
				},
			},
			arrival: '2020-06-11T18:44:00+02:00',
			plannedArrival: '2020-06-11T18:44:00+02:00',
			arrivalDelay: null,
			arrivalPlatform: '2',
			plannedArrivalPlatform: '2',
			arrivalPrognosisType: 'prognosed',
			departure: '2020-06-11T18:46:00+02:00',
			plannedDeparture: '2020-06-11T18:46:00+02:00',
			departureDelay: null,
			departurePlatform: '2',
			plannedDeparturePlatform: '2',
			departurePrognosisType: 'prognosed',
			remarks: [
				öbbWestbahnTickets,
				corona,
			],
		},
		{
			stop: {
				type: 'stop',
				id: '8100017',
				name: 'Attnang-Puchheim Bahnhof',
				location: {
					type: 'location',
					id: '8100017',
					latitude: 48.012654,
					longitude: 13.720883,
				},
				products: {
					nationalExpress: true,
					national: true,
					interregional: true,
					regional: true,
					suburban: true,
					bus: false,
					ferry: false,
					subway: false,
					tram: false,
					onCall: false,
				},
			},
			arrival: '2020-06-11T18:58:00+02:00',
			plannedArrival: '2020-06-11T18:58:00+02:00',
			arrivalDelay: null,
			arrivalPlatform: '3',
			plannedArrivalPlatform: '3',
			arrivalPrognosisType: null,
			departure: '2020-06-11T19:00:00+02:00',
			plannedDeparture: '2020-06-11T19:00:00+02:00',
			departureDelay: null,
			departurePlatform: '3',
			plannedDeparturePlatform: '3',
			departurePrognosisType: null,
			remarks: [
				öbbWestbahnTickets,
				corona,
			],
		},
		{
			stop: {
				type: 'stop',
				id: '8100507',
				name: 'Vöcklabruck Bahnhof',
				location: {
					type: 'location',
					id: '8100507',
					latitude: 48.010002,
					longitude: 13.663936,
				},
				products: {
					nationalExpress: true,
					national: false,
					interregional: true,
					regional: true,
					suburban: true,
					bus: false,
					ferry: false,
					subway: false,
					tram: false,
					onCall: false,
				},
			},
			arrival: '2020-06-11T19:04:00+02:00',
			plannedArrival: '2020-06-11T19:04:00+02:00',
			arrivalDelay: null,
			arrivalPlatform: '2',
			plannedArrivalPlatform: '2',
			arrivalPrognosisType: 'prognosed',
			departure: '2020-06-11T19:06:00+02:00',
			plannedDeparture: '2020-06-11T19:06:00+02:00',
			departureDelay: null,
			departurePlatform: '2',
			plannedDeparturePlatform: '2',
			departurePrognosisType: 'prognosed',
			remarks: [
				öbbWestbahnTickets,
				corona,
			],
		},
		{
			stop: {
				type: 'stop',
				id: '8100134',
				name: 'Neumarkt-Köstendorf Bahnhof',
				location: {
					type: 'location',
					id: '8100134',
					latitude: 47.954512,
					longitude: 13.224714,
				},
				products: {
					nationalExpress: true,
					national: false,
					interregional: true,
					regional: true,
					suburban: true,
					bus: false,
					ferry: false,
					subway: false,
					tram: false,
					onCall: false,
				},
			},
			arrival: '2020-06-11T19:30:00+02:00',
			plannedArrival: '2020-06-11T19:30:00+02:00',
			arrivalDelay: null,
			arrivalPlatform: '2',
			plannedArrivalPlatform: '2',
			arrivalPrognosisType: 'prognosed',
			departure: '2020-06-11T19:31:00+02:00',
			plannedDeparture: '2020-06-11T19:31:00+02:00',
			departureDelay: null,
			departurePlatform: '2',
			plannedDeparturePlatform: '2',
			departurePrognosisType: 'prognosed',
			remarks: [
				öbbWestbahnTickets,
				corona,
			],
		},
		{
			stop: salzburgHbf,
			arrival: '2020-06-11T19:48:00+02:00',
			plannedArrival: '2020-06-11T19:48:00+02:00',
			arrivalDelay: null,
			arrivalPlatform: '6A-C',
			plannedArrivalPlatform: '4A-C',
			arrivalPrognosisType: 'prognosed',
			departure: null,
			plannedDeparture: null,
			departureDelay: null,
			departurePlatform: null,
			plannedDeparturePlatform: null,
			departurePrognosisType: null,
			remarks: [
				öbbWestbahnTickets,
				corona,
			],
		},
	],
	remarks: [
		{
			type: 'hint',
			code: 'FR',
			text: 'Fahrradmitnahme reservierungspflichtig',
		},
		{
			type: 'hint',
			code: 'FK',
			text: 'Fahrradmitnahme begrenzt möglich',
		},
		{type: 'hint', code: 'RM', text: 'Reservierung möglich'},
		{type: 'hint', code: 'BR', text: 'Bordrestaurant'},
		{type: 'hint', code: 'RO', text: 'Rollstuhlstellplatz'},
		{
			type: 'hint',
			code: 'OA',
			text: 'Rollstuhlstellplatz - Voranmeldung unter +43 5 1717',
		},
		{
			type: 'hint',
			code: 'EF',
			text: 'Fahrzeuggebundene Einstiegshilfe',
		},
		{type: 'hint', code: 'OC', text: 'rollstuhltaugliches WC'},
		{type: 'hint', code: 'HD', text: 'Ruhezone'},
		{type: 'hint', code: 'KN', text: 'Familienzone'},
		{type: 'hint', code: 'WV', text: 'WLAN verfügbar'},
		{
			id: '483653',
			type: 'warning',
			summary: 'Aktuelle Lage',
			text: 'Wegen der aktuellen Corona-Situation wurde <b>der Fahrplan österreichweit angepasst</b>.\n'
			+ 'Der Fernverkehr fährt innerhalb Österreichs wieder verstärkt. Der Regelbetrieb für S-Bahnen und Regionalzüge ist wieder aufgenommen.\n'
			+ 'Einschränkungen im grenzüberschreitenden Verkehr bleiben bis auf Weiteres bestehen.\n'
			+ 'Informationen dazu erhalten Sie auf SCOTTY mobil, im Internet auf <a href="https://www.oebb.at">www.oebb.at</a> und beim <a href="https://www.oebb.at/de/reiseplanung-services/kundenservice">ÖBB-Kundenservice</a> unter +43-5-1717.\n'
			+ ' Wir bitten Sie in allen <b>öffentlichen Verkehrsmitteln und im gesamten Bahnhofsbereich</b> ein <b>Mund-Nasenschutz</b> zu tragen. Bitte halten Sie auch einen <b> Sicherheitsabstand </b> zu anderen Personen ein. Nähere Informationen des Bundesministeriums finden Sie <a href="https://kundeninformation-pv.oebb.at/dam/verkehrsauskunft/extern/2020/2020_04/Fahrgast-Charta_April_2020/Fahrgast-Charta_April_2020.pdf">hier</a>.\n',
			icon: {type: 'HIM5', title: null},
			priority: 100,
			category: 5,
			products: {
				nationalExpress: true,
				national: true,
				interregional: true,
				regional: true,
				suburban: true,
				bus: false,
				ferry: false,
				subway: false,
				tram: false,
				onCall: false,
			},
			validFrom: '2020-05-18T00:00:00+02:00',
			validUntil: '2020-06-30T23:59:00+02:00',
			modified: '2020-05-28T13:47:56+02:00',
		},
	],
	polyline: {
		type: 'FeatureCollection',
		features: [
			feature(point(16.56242, 48.12117), wienFlughafen),
			feature(point(16.55361, 48.12577)),
			feature(point(16.55205, 48.12635)),
			feature(point(16.54853, 48.12746)),
			feature(point(16.5384, 48.13162)),
			feature(point(16.53565, 48.13257)),
			feature(point(16.53354, 48.13306)),
			feature(point(16.53193, 48.13332)),
			feature(point(16.51302, 48.13531)),
			feature(point(16.50827, 48.13636)),
			feature(point(16.50164, 48.13797)),
			feature(point(16.49571, 48.13868)),
			feature(point(16.49403, 48.13896)),
			feature(point(16.4922, 48.13964)),
			feature(point(16.48843, 48.14188)),
			feature(point(16.48721, 48.14217)),
			feature(point(16.48356, 48.14256)),
			feature(point(16.48265, 48.1429)),
			feature(point(16.48169, 48.14351)),
			feature(point(16.47867, 48.14553)),
			feature(point(16.47768, 48.14582)),
			feature(point(16.47542, 48.14607)),
			feature(point(16.47459, 48.14629)),
			feature(point(16.47184, 48.14784)),
			feature(point(16.47092, 48.14817)),
			feature(point(16.46949, 48.14826)),
			feature(point(16.46883, 48.14818)),
			feature(point(16.46809, 48.14795)),
			feature(point(16.46714, 48.14741)),
			feature(point(16.46508, 48.14598)),
			feature(point(16.46413, 48.14518)),
			feature(point(16.46028, 48.14253)),
			feature(point(16.45611, 48.14019)),
			feature(point(16.45478, 48.13955)),
			feature(point(16.45367, 48.13921)),
			feature(point(16.45206, 48.13895)),
			feature(point(16.44579, 48.13862)),
			feature(point(16.44108, 48.13867)),
			{
				type: 'Feature',
				properties: {
					type: 'stop',
					id: '8199506',
					name: 'Wien Zentralverschiebebahnhof Brücke (Tarifpunkt)',
					location: {
						type: 'location',
						id: '8199506',
						latitude: 48.139555,
						longitude: 16.435221,
					},
					products: {
						nationalExpress: false,
						national: false,
						interregional: false,
						regional: false,
						suburban: false,
						bus: false,
						ferry: false,
						subway: false,
						tram: false,
						onCall: false,
					},
				},
				geometry: point(16.43523, 48.13958),
			},
			feature(point(16.43308, 48.14005)),
			feature(point(16.4315, 48.14055)),
			feature(point(16.4296, 48.1414)),
			feature(point(16.42884, 48.14198)),
			feature(point(16.42837, 48.14252)),
			feature(point(16.42788, 48.14351)),
			feature(point(16.42764, 48.14438)),
			feature(point(16.42578, 48.1475)),
			feature(point(16.42492, 48.14904)),
			feature(point(16.42432, 48.15164)),
			feature(point(16.42389, 48.1524)),
			feature(point(16.42344, 48.15292)),
			feature(point(16.40692, 48.16718)),
			feature(point(16.40395, 48.16938)),
			feature(point(16.3974, 48.17386)),
			feature(point(16.39395, 48.17603)),
			feature(point(16.39141, 48.17703)),
			feature(point(16.38999, 48.17785)),
			feature(point(16.3879, 48.17952)),
			feature(point(16.38539, 48.18203)),
			feature(point(16.38373, 48.18306)),
			feature(point(16.38225, 48.18378)),
			feature(point(16.38137, 48.1841)),
			feature(point(16.38057, 48.18427)),
			{
				type: 'Feature',
				properties: {
					type: 'stop',
					id: '8103000',
					name: 'Wien Hbf',
					location: {
						type: 'location',
						id: '8103000',
						latitude: 48.184564,
						longitude: 16.378526,
					},
					products: {
						nationalExpress: true,
						national: true,
						interregional: true,
						regional: true,
						suburban: true,
						bus: false,
						ferry: false,
						subway: false,
						tram: false,
						onCall: false,
					},
				},
				geometry: point(16.37852, 48.18457),
			},
			feature(point(16.37616, 48.18488)),
			feature(point(16.37427, 48.18495)),
			feature(point(16.3732, 48.18479)),
			feature(point(16.37159, 48.18428)),
			feature(point(16.36956, 48.18326)),
			feature(point(16.3632, 48.18116)),
			feature(point(16.35812, 48.17986)),
			feature(point(16.35538, 48.17877)),
			feature(point(16.3513, 48.17704)),
			feature(point(16.34788, 48.17621)),
			feature(point(16.34571, 48.17594)),
			feature(point(16.34305, 48.17587)),
			feature(point(16.3396, 48.17559)),
			{
				type: 'Feature',
				properties: {
					type: 'stop',
					id: '8100514',
					name: 'Wien Meidling Bahnhof',
					location: {
						type: 'location',
						id: '8100514',
						latitude: 48.174585,
						longitude: 16.333733,
					},
					products: {
						nationalExpress: true,
						national: true,
						interregional: true,
						regional: true,
						suburban: true,
						bus: false,
						ferry: false,
						subway: false,
						tram: false,
						onCall: false,
					},
				},
				geometry: point(16.33373, 48.17459),
			},
			feature(point(16.3287, 48.17346)),
			feature(point(16.32447, 48.17195)),
			feature(point(16.32262, 48.17111)),
			feature(point(16.32135, 48.17061)),
			feature(point(16.31849, 48.1692)),
			feature(point(16.3169, 48.16888)),
			feature(point(16.31384, 48.16866)),
			feature(point(16.30721, 48.16911)),
			feature(point(16.30336, 48.16968)),
			feature(point(16.287, 48.17295)),
			feature(point(16.28453, 48.17369)),
			feature(point(16.28222, 48.17465)),
			feature(point(16.28074, 48.1754)),
			feature(point(16.27336, 48.18013)),
			feature(point(16.25677, 48.19148)),
			feature(point(16.24185, 48.20066)),
			feature(point(16.23918, 48.20207)),
			feature(point(16.23709, 48.20303)),
			feature(point(16.23607, 48.20374)),
			feature(point(16.23544, 48.20448)),
			feature(point(16.23378, 48.20716)),
			feature(point(16.23269, 48.20805)),
			feature(point(16.23153, 48.20867)),
			feature(point(16.22958, 48.20946)),
			feature(point(16.22786, 48.20999)),
			feature(point(16.22527, 48.21044)),
			feature(point(16.22012, 48.21069)),
			feature(point(16.21801, 48.21109)),
			feature(point(16.21383, 48.21165)),
			feature(point(16.20888, 48.21268)),
			feature(point(16.19959, 48.21534)),
			{
				type: 'Feature',
				properties: {
					type: 'stop',
					id: '8199501',
					name: 'Wien Hadersdorf Stadtgrenze (Tarifpunkt)',
					location: {
						type: 'location',
						id: '8199501',
						latitude: 48.216493,
						longitude: 16.196431,
					},
					products: {
						nationalExpress: false,
						national: false,
						interregional: false,
						regional: false,
						suburban: false,
						bus: false,
						ferry: false,
						subway: false,
						tram: false,
						onCall: false,
					},
				},
				geometry: point(16.19643, 48.2165),
			},
			feature(point(16.19266, 48.21819)),
			feature(point(16.18994, 48.2197)),
			feature(point(16.09796, 48.27616)),
			feature(point(16.08989, 48.2809)),
			feature(point(16.08354, 48.28412)),
			feature(point(16.08053, 48.28544)),
			feature(point(16.0775, 48.28665)),
			feature(point(16.07149, 48.28874)),
			feature(point(16.06795, 48.28978)),
			feature(point(16.06361, 48.29086)),
			feature(point(16.05734, 48.29212)),
			feature(point(16.0519, 48.29291)),
			feature(point(16.04635, 48.29346)),
			feature(point(16.04221, 48.2937)),
			feature(point(16.02645, 48.29421)),
			feature(point(16.0087, 48.29478)),
			{
				type: 'Feature',
				properties: {
					type: 'stop',
					id: '8102059',
					name: 'Tullnerfeld Bahnhof',
					location: {
						type: 'location',
						id: '8102059',
						latitude: 48.295167,
						longitude: 15.996538,
					},
					products: {
						nationalExpress: true,
						national: true,
						interregional: true,
						regional: true,
						suburban: true,
						bus: false,
						ferry: false,
						subway: false,
						tram: false,
						onCall: false,
					},
				},
				geometry: point(15.99654, 48.29517),
			},
			feature(point(15.97902, 48.29573)),
			feature(point(15.94482, 48.29681)),
			feature(point(15.94063, 48.29685)),
			feature(point(15.93795, 48.29675)),
			feature(point(15.93412, 48.29639)),
			feature(point(15.93034, 48.29578)),
			feature(point(15.92658, 48.29492)),
			feature(point(15.92391, 48.29413)),
			feature(point(15.92069, 48.29296)),
			feature(point(15.91742, 48.29148)),
			feature(point(15.91533, 48.29037)),
			feature(point(15.91337, 48.28917)),
			feature(point(15.91146, 48.28784)),
			feature(point(15.90349, 48.28144)),
			feature(point(15.90192, 48.28033)),
			feature(point(15.89945, 48.27881)),
			feature(point(15.89683, 48.27743)),
			feature(point(15.89357, 48.27602)),
			feature(point(15.89215, 48.2755)),
			feature(point(15.88994, 48.27476)),
			feature(point(15.88621, 48.27379)),
			feature(point(15.88405, 48.27334)),
			feature(point(15.88074, 48.27282)),
			feature(point(15.87804, 48.27253)),
			feature(point(15.87464, 48.27236)),
			feature(point(15.86345, 48.27246)),
			feature(point(15.85841, 48.27217)),
			feature(point(15.84732, 48.27105)),
			feature(point(15.84301, 48.27028)),
			feature(point(15.83939, 48.26933)),
			feature(point(15.83578, 48.26812)),
			feature(point(15.83366, 48.26726)),
			feature(point(15.83145, 48.26622)),
			feature(point(15.82933, 48.26508)),
			feature(point(15.82199, 48.26071)),
			feature(point(15.81797, 48.25869)),
			feature(point(15.81488, 48.25737)),
			feature(point(15.80652, 48.25427)),
			feature(point(15.80278, 48.2526)),
			feature(point(15.79184, 48.24659)),
			feature(point(15.78857, 48.24496)),
			feature(point(15.78473, 48.24345)),
			feature(point(15.78093, 48.24229)),
			feature(point(15.77774, 48.24156)),
			feature(point(15.77512, 48.24109)),
			feature(point(15.76997, 48.24053)),
			feature(point(15.72683, 48.23812)),
			feature(point(15.72213, 48.2378)),
			feature(point(15.71944, 48.23749)),
			feature(point(15.71678, 48.23705)),
			feature(point(15.71438, 48.23654)),
			feature(point(15.71083, 48.23557)),
			feature(point(15.70843, 48.23477)),
			feature(point(15.70523, 48.23349)),
			feature(point(15.70262, 48.2322)),
			feature(point(15.70062, 48.23107)),
			feature(point(15.69856, 48.22974)),
			feature(point(15.6886, 48.22274)),
			feature(point(15.68492, 48.22033)),
			feature(point(15.683, 48.21924)),
			feature(point(15.68002, 48.21776)),
			feature(point(15.67732, 48.21663)),
			feature(point(15.66992, 48.21404)),
			feature(point(15.65321, 48.20885)),
			feature(point(15.65071, 48.2082)),
			feature(point(15.64862, 48.20781)),
			feature(point(15.64536, 48.20744)),
			feature(point(15.64203, 48.20735)),
			feature(point(15.63031, 48.20793)),
			{
				type: 'Feature',
				properties: {
					type: 'stop',
					id: '8100008',
					name: 'St.Pölten Hbf',
					location: {
						type: 'location',
						id: '8100008',
						latitude: 48.20825,
						longitude: 15.624681,
					},
					products: {
						nationalExpress: true,
						national: true,
						interregional: true,
						regional: true,
						suburban: true,
						bus: false,
						ferry: false,
						subway: false,
						tram: false,
						onCall: false,
					},
				},
				geometry: point(15.62468, 48.20825),
			},
			feature(point(15.62117, 48.20838)),
			feature(point(15.61982, 48.20854)),
			feature(point(15.61821, 48.20902)),
			feature(point(15.61413, 48.21118)),
			feature(point(15.60805, 48.21413)),
			feature(point(15.60605, 48.21508)),
			feature(point(15.60402, 48.21586)),
			feature(point(15.60237, 48.21633)),
			feature(point(15.59996, 48.21677)),
			feature(point(15.59761, 48.21695)),
			feature(point(15.5954, 48.21691)),
			feature(point(15.59336, 48.21669)),
			feature(point(15.59118, 48.21624)),
			feature(point(15.58866, 48.21547)),
			feature(point(15.58125, 48.21291)),
			feature(point(15.57816, 48.21205)),
			feature(point(15.57525, 48.21137)),
			feature(point(15.57218, 48.21081)),
			feature(point(15.56874, 48.21036)),
			feature(point(15.55863, 48.20953)),
			feature(point(15.55466, 48.20899)),
			feature(point(15.55091, 48.20827)),
			feature(point(15.52555, 48.20293)),
			feature(point(15.50902, 48.19947)),
			feature(point(15.49597, 48.19615)),
			feature(point(15.46958, 48.1894)),
			feature(point(15.46597, 48.18871)),
			feature(point(15.46394, 48.18843)),
			feature(point(15.46094, 48.18814)),
			feature(point(15.45806, 48.18803)),
			feature(point(15.4516, 48.18796)),
			feature(point(15.42878, 48.18804)),
			feature(point(15.41872, 48.18804)),
			feature(point(15.41568, 48.18824)),
			feature(point(15.41317, 48.18851)),
			feature(point(15.41001, 48.18902)),
			feature(point(15.40675, 48.18975)),
			feature(point(15.40366, 48.19066)),
			feature(point(15.39953, 48.19223)),
			feature(point(15.39569, 48.19417)),
			feature(point(15.39322, 48.19571)),
			feature(point(15.39146, 48.197)),
			feature(point(15.38898, 48.19916)),
			feature(point(15.38206, 48.2062)),
			feature(point(15.37987, 48.208)),
			feature(point(15.37799, 48.2093)),
			feature(point(15.37546, 48.21079)),
			feature(point(15.37203, 48.21246)),
			feature(point(15.36799, 48.21401)),
			feature(point(15.36482, 48.21495)),
			feature(point(15.36021, 48.21595)),
			feature(point(15.35507, 48.21662)),
			feature(point(15.31975, 48.21877)),
			feature(point(15.31558, 48.2191)),
			feature(point(15.30826, 48.21986)),
			feature(point(15.30179, 48.2205)),
			feature(point(15.29701, 48.22073)),
			feature(point(15.29277, 48.22066)),
			feature(point(15.29014, 48.22048)),
			feature(point(15.28704, 48.22015)),
			feature(point(15.28341, 48.21956)),
			feature(point(15.27838, 48.21841)),
			feature(point(15.27464, 48.21726)),
			feature(point(15.26654, 48.21426)),
			feature(point(15.26199, 48.21273)),
			feature(point(15.25623, 48.21117)),
			feature(point(15.25078, 48.21007)),
			feature(point(15.24512, 48.20926)),
			feature(point(15.23982, 48.20881)),
			feature(point(15.22297, 48.20813)),
			{
				type: 'Feature',
				properties: {
					type: 'stop',
					id: '8100006',
					name: 'Pöchlarn Bahnhof',
					location: {
						type: 'location',
						id: '8100006',
						latitude: 48.207944,
						longitude: 15.216346,
					},
					products: {
						nationalExpress: false,
						national: false,
						interregional: false,
						regional: true,
						suburban: false,
						bus: false,
						ferry: false,
						subway: false,
						tram: false,
						onCall: false,
					},
				},
				geometry: point(15.21635, 48.20794),
			},
			feature(point(15.20289, 48.20773)),
			feature(point(15.18148, 48.20714)),
			feature(point(15.1755, 48.20651)),
			feature(point(15.1709, 48.20571)),
			feature(point(15.1666, 48.20463)),
			feature(point(15.163, 48.20347)),
			feature(point(15.15988, 48.20226)),
			feature(point(15.15803, 48.20143)),
			feature(point(15.14356, 48.19403)),
			feature(point(15.1411, 48.19268)),
			feature(point(15.13792, 48.19074)),
			feature(point(15.13534, 48.18895)),
			feature(point(15.13338, 48.18745)),
			feature(point(15.12894, 48.18349)),
			feature(point(15.12201, 48.17666)),
			feature(point(15.12056, 48.17552)),
			feature(point(15.10642, 48.16329)),
			feature(point(15.1033, 48.16108)),
			feature(point(15.09951, 48.15887)),
			feature(point(15.09486, 48.15629)),
			feature(point(15.08907, 48.15292)),
			feature(point(15.08608, 48.1516)),
			feature(point(15.08298, 48.15068)),
			feature(point(15.05556, 48.14346)),
			feature(point(15.0265, 48.13581)),
			feature(point(15.02285, 48.13477)),
			feature(point(15.01982, 48.13358)),
			feature(point(15.0087, 48.12808)),
			feature(point(15.00659, 48.12729)),
			feature(point(15.0036, 48.12645)),
			feature(point(15.00063, 48.12592)),
			feature(point(14.998, 48.12568)),
			feature(point(14.97874, 48.12502)),
			feature(point(14.88988, 48.122)),
			{
				type: 'Feature',
				properties: {
					type: 'stop',
					id: '8100012',
					name: 'Amstetten NÖ Bahnhof',
					location: {
						type: 'location',
						id: '8100012',
						latitude: 48.121477,
						longitude: 14.878199,
					},
					products: {
						nationalExpress: true,
						national: false,
						interregional: true,
						regional: true,
						suburban: false,
						bus: false,
						ferry: false,
						subway: false,
						tram: false,
						onCall: false,
					},
				},
				geometry: point(14.8782, 48.12148),
			},
			feature(point(14.87397, 48.1214)),
			feature(point(14.87116, 48.12117)),
			feature(point(14.85358, 48.11841)),
			feature(point(14.85121, 48.11779)),
			feature(point(14.84926, 48.11704)),
			feature(point(14.8442, 48.11441)),
			feature(point(14.8276, 48.1056)),
			feature(point(14.82349, 48.10362)),
			feature(point(14.82055, 48.10239)),
			feature(point(14.8011, 48.09499)),
			feature(point(14.79281, 48.09187)),
			feature(point(14.78953, 48.0904)),
			feature(point(14.78671, 48.0889)),
			feature(point(14.7563, 48.06959)),
			feature(point(14.74582, 48.06393)),
			feature(point(14.74051, 48.06177)),
			feature(point(14.7379, 48.0609)),
			feature(point(14.7354, 48.06019)),
			feature(point(14.73185, 48.05941)),
			feature(point(14.72857, 48.05889)),
			feature(point(14.6986, 48.05512)),
			feature(point(14.67952, 48.05272)),
			feature(point(14.67446, 48.05228)),
			feature(point(14.67053, 48.05219)),
			feature(point(14.66634, 48.05233)),
			feature(point(14.66353, 48.05258)),
			feature(point(14.65758, 48.05334)),
			feature(point(14.65089, 48.05424)),
			feature(point(14.64547, 48.05534)),
			feature(point(14.64069, 48.05671)),
			feature(point(14.6361, 48.05838)),
			feature(point(14.63165, 48.06037)),
			feature(point(14.62725, 48.06276)),
			feature(point(14.62426, 48.06469)),
			feature(point(14.62272, 48.0658)),
			feature(point(14.61803, 48.06967)),
			feature(point(14.61308, 48.07503)),
			feature(point(14.60949, 48.07919)),
			feature(point(14.60717, 48.08288)),
			feature(point(14.60568, 48.08591)),
			feature(point(14.60081, 48.10091)),
			feature(point(14.59962, 48.10387)),
			feature(point(14.59848, 48.10598)),
			feature(point(14.59722, 48.10789)),
			feature(point(14.59594, 48.10955)),
			feature(point(14.5941, 48.11158)),
			feature(point(14.59156, 48.1139)),
			feature(point(14.58956, 48.11545)),
			feature(point(14.58614, 48.1177)),
			feature(point(14.58328, 48.11926)),
			feature(point(14.57889, 48.12124)),
			feature(point(14.55178, 48.13197)),
			feature(point(14.54899, 48.13328)),
			feature(point(14.54664, 48.13459)),
			feature(point(14.54508, 48.13557)),
			feature(point(14.54273, 48.13729)),
			feature(point(14.54069, 48.13906)),
			feature(point(14.5386, 48.14126)),
			feature(point(14.53706, 48.14324)),
			feature(point(14.53537, 48.14607)),
			feature(point(14.53407, 48.14928)),
			feature(point(14.53078, 48.16086)),
			feature(point(14.52995, 48.16303)),
			feature(point(14.52922, 48.16546)),
			feature(point(14.52794, 48.16841)),
			feature(point(14.52441, 48.17451)),
			feature(point(14.52407, 48.17533)),
			{
				type: 'Feature',
				properties: {
					type: 'stop',
					id: '8100009',
					name: 'St.Valentin Bahnhof',
					location: {
						type: 'location',
						id: '8100009',
						latitude: 48.17873,
						longitude: 14.522083,
					},
					products: {
						nationalExpress: true,
						national: false,
						interregional: true,
						regional: true,
						suburban: true,
						bus: false,
						ferry: false,
						subway: false,
						tram: false,
						onCall: false,
					},
				},
				geometry: point(14.52208, 48.17873),
			},
			feature(point(14.51228, 48.19552)),
			feature(point(14.51102, 48.198)),
			feature(point(14.51053, 48.1992)),
			feature(point(14.50964, 48.2024)),
			feature(point(14.50856, 48.2076)),
			feature(point(14.50741, 48.21079)),
			feature(point(14.50579, 48.21367)),
			feature(point(14.50434, 48.21561)),
			feature(point(14.50287, 48.21724)),
			feature(point(14.50105, 48.21895)),
			feature(point(14.49957, 48.22014)),
			feature(point(14.49747, 48.2216)),
			feature(point(14.49582, 48.22261)),
			feature(point(14.49373, 48.22373)),
			feature(point(14.49157, 48.22473)),
			feature(point(14.48705, 48.2264)),
			feature(point(14.4827, 48.22755)),
			feature(point(14.4785, 48.2283)),
			feature(point(14.47449, 48.22869)),
			feature(point(14.47073, 48.22881)),
			feature(point(14.46855, 48.22877)),
			feature(point(14.4654, 48.22856)),
			feature(point(14.44769, 48.22681)),
			feature(point(14.44284, 48.22663)),
			feature(point(14.43731, 48.22678)),
			feature(point(14.43279, 48.22718)),
			feature(point(14.42805, 48.2279)),
			feature(point(14.42386, 48.22877)),
			feature(point(14.41824, 48.23025)),
			feature(point(14.39836, 48.23674)),
			feature(point(14.37861, 48.24303)),
			feature(point(14.35378, 48.25097)),
			feature(point(14.35062, 48.25163)),
			feature(point(14.34598, 48.25198)),
			feature(point(14.34183, 48.25216)),
			feature(point(14.34039, 48.25233)),
			feature(point(14.33781, 48.25287)),
			feature(point(14.3353, 48.25368)),
			feature(point(14.33086, 48.25568)),
			feature(point(14.32704, 48.2577)),
			feature(point(14.32294, 48.25962)),
			feature(point(14.32117, 48.2607)),
			feature(point(14.32001, 48.26174)),
			feature(point(14.31955, 48.26253)),
			feature(point(14.31849, 48.26583)),
			feature(point(14.31818, 48.26907)),
			feature(point(14.31692, 48.27341)),
			feature(point(14.31682, 48.2743)),
			feature(point(14.31699, 48.27799)),
			feature(point(14.31667, 48.28049)),
			feature(point(14.31627, 48.2817)),
			feature(point(14.31438, 48.28533)),
			feature(point(14.31285, 48.28978)),
			feature(point(14.31235, 48.29111)),
			feature(point(14.31166, 48.29201)),
			feature(point(14.3075, 48.29504)),
			feature(point(14.30646, 48.2956)),
			feature(point(14.30542, 48.296)),
			feature(point(14.30372, 48.29643)),
			feature(point(14.30238, 48.29657)),
			feature(point(14.30121, 48.29654)),
			feature(point(14.2997, 48.29627)),
			feature(point(14.29806, 48.29579)),
			feature(point(14.29636, 48.29502)),
			feature(point(14.29528, 48.29426)),
			feature(point(14.29462, 48.29361)),
			{
				type: 'Feature',
				properties: {
					type: 'stop',
					id: '8100013',
					name: 'Linz/Donau Hbf',
					location: {
						type: 'location',
						id: '8100013',
						latitude: 48.29016,
						longitude: 14.291941,
					},
					products: {
						nationalExpress: true,
						national: true,
						interregional: true,
						regional: true,
						suburban: true,
						bus: false,
						ferry: false,
						subway: false,
						tram: false,
						onCall: false,
					},
				},
				geometry: point(14.29194, 48.29016),
			},
			feature(point(14.28644, 48.28392)),
			feature(point(14.28542, 48.28301)),
			feature(point(14.28373, 48.28195)),
			feature(point(14.27725, 48.27805)),
			feature(point(14.27423, 48.27615)),
			feature(point(14.27311, 48.27557)),
			feature(point(14.27122, 48.27485)),
			feature(point(14.26951, 48.27443)),
			feature(point(14.2677, 48.27417)),
			feature(point(14.26624, 48.27409)),
			{
				type: 'Feature',
				properties: {
					type: 'stop',
					id: '8101165',
					name: 'Leonding (Westbahn) Bahnhof',
					location: {
						type: 'location',
						id: '8101165',
						latitude: 48.274015,
						longitude: 14.253871,
					},
					products: {
						nationalExpress: false,
						national: false,
						interregional: false,
						regional: true,
						suburban: true,
						bus: false,
						ferry: false,
						subway: false,
						tram: false,
						onCall: false,
					},
				},
				geometry: point(14.25387, 48.27402),
			},
			feature(point(14.24863, 48.27396)),
			feature(point(14.24531, 48.27367)),
			feature(point(14.24369, 48.27342)),
			feature(point(14.2413, 48.2729)),
			feature(point(14.23926, 48.27233)),
			feature(point(14.23767, 48.27176)),
			feature(point(14.23507, 48.27061)),
			{
				type: 'Feature',
				properties: {
					type: 'stop',
					id: '8101389',
					name: 'Pasching b.Linz Bahnhof',
					location: {
						type: 'location',
						id: '8101389',
						latitude: 48.257448,
						longitude: 14.209339,
					},
					products: {
						nationalExpress: false,
						national: false,
						interregional: false,
						regional: true,
						suburban: true,
						bus: false,
						ferry: false,
						subway: false,
						tram: false,
						onCall: false,
					},
				},
				geometry: point(14.20934, 48.25745),
			},
			feature(point(14.18643, 48.24575)),
			feature(point(14.15117, 48.2276)),
			feature(point(14.11555, 48.2093)),
			{
				type: 'Feature',
				properties: {
					type: 'stop',
					id: '8101204',
					name: 'Marchtrenk Bahnhof',
					location: {
						type: 'location',
						id: '8101204',
						latitude: 48.200996,
						longitude: 14.099491,
					},
					products: {
						nationalExpress: false,
						national: false,
						interregional: false,
						regional: true,
						suburban: true,
						bus: false,
						ferry: false,
						subway: false,
						tram: false,
						onCall: false,
					},
				},
				geometry: point(14.09949, 48.201),
			},
			feature(point(14.07166, 48.18672)),
			feature(point(14.03896, 48.16978)),
			feature(point(14.03774, 48.16923)),
			feature(point(14.03657, 48.16883)),
			feature(point(14.03336, 48.16786)),
			feature(point(14.03021, 48.16709)),
			{
				type: 'Feature',
				properties: {
					type: 'stop',
					id: '8100014',
					name: 'Wels Hbf',
					location: {
						type: 'location',
						id: '8100014',
						latitude: 48.166208,
						longitude: 14.027271,
					},
					products: {
						nationalExpress: true,
						national: true,
						interregional: true,
						regional: true,
						suburban: true,
						bus: false,
						ferry: false,
						subway: false,
						tram: false,
						onCall: false,
					},
				},
				geometry: point(14.02727, 48.16621),
			},
			feature(point(14.02361, 48.1651)),
			feature(point(14.01975, 48.16375)),
			feature(point(14.01746, 48.16305)),
			feature(point(13.97756, 48.15096)),
			feature(point(13.97456, 48.14994)),
			feature(point(13.97158, 48.14874)),
			feature(point(13.96868, 48.14738)),
			feature(point(13.96543, 48.14556)),
			feature(point(13.9462, 48.13265)),
			feature(point(13.90644, 48.10604)),
			{
				type: 'Feature',
				properties: {
					type: 'stop',
					id: '8199518',
					name: 'Lambach OÖ Ost (Tarifpunkt)',
					location: {
						type: 'location',
						id: '8199518',
						latitude: 48.101198,
						longitude: 13.899058,
					},
					products: {
						nationalExpress: false,
						national: false,
						interregional: false,
						regional: false,
						suburban: false,
						bus: false,
						ferry: false,
						subway: false,
						tram: false,
						onCall: false,
					},
				},
				geometry: point(13.90023, 48.10178),
			},
			feature(point(13.89709, 48.09997)),
			feature(point(13.89427, 48.09856)),
			feature(point(13.89074, 48.09717)),
			feature(point(13.88624, 48.09585)),
			feature(point(13.88208, 48.09502)),
			feature(point(13.87871, 48.0946)),
			feature(point(13.87528, 48.09438)),
			{
				type: 'Feature',
				properties: {
					type: 'stop',
					id: '8199519',
					name: 'Lambach OÖ West (Tarifpunkt)',
					location: {
						type: 'location',
						id: '8199519',
						latitude: 48.094321,
						longitude: 13.872297,
					},
					products: {
						nationalExpress: false,
						national: false,
						interregional: false,
						regional: false,
						suburban: false,
						bus: false,
						ferry: false,
						subway: false,
						tram: false,
						onCall: false,
					},
				},
				geometry: point(13.87004, 48.09435),
			},
			feature(point(13.84047, 48.09589)),
			feature(point(13.83635, 48.09583)),
			{
				type: 'Feature',
				properties: {
					type: 'stop',
					id: '8101278',
					name: 'Neukirchen b.Lambach Bahnhof',
					location: {
						type: 'location',
						id: '8101278',
						latitude: 48.095471,
						longitude: 13.832529,
					},
					products: {
						nationalExpress: false,
						national: false,
						interregional: false,
						regional: true,
						suburban: true,
						bus: false,
						ferry: false,
						subway: false,
						tram: false,
						onCall: false,
					},
				},
				geometry: point(13.83253, 48.09547),
			},
			feature(point(13.82899, 48.09485)),
			feature(point(13.82521, 48.09386)),
			feature(point(13.82181, 48.09265)),
			feature(point(13.81872, 48.09122)),
			feature(point(13.81543, 48.08925)),
			feature(point(13.80098, 48.07875)),
			feature(point(13.79726, 48.07573)),
			feature(point(13.79086, 48.06959)),
			feature(point(13.7873, 48.06659)),
			feature(point(13.78388, 48.06421)),
			feature(point(13.77801, 48.06062)),
			feature(point(13.76838, 48.05425)),
			feature(point(13.75653, 48.04621)),
			feature(point(13.74906, 48.04136)),
			feature(point(13.74584, 48.03889)),
			feature(point(13.74349, 48.03663)),
			feature(point(13.72301, 48.01499)),
			{
				type: 'Feature',
				properties: {
					type: 'stop',
					id: '8100017',
					name: 'Attnang-Puchheim Bahnhof',
					location: {
						type: 'location',
						id: '8100017',
						latitude: 48.012654,
						longitude: 13.720883,
					},
					products: {
						nationalExpress: true,
						national: true,
						interregional: true,
						regional: true,
						suburban: true,
						bus: false,
						ferry: false,
						subway: false,
						tram: false,
						onCall: false,
					},
				},
				geometry: point(13.72088, 48.01266),
			},
			feature(point(13.71806, 48.00964)),
			feature(point(13.71741, 48.00904)),
			feature(point(13.71668, 48.00857)),
			feature(point(13.71509, 48.00766)),
			feature(point(13.71436, 48.00741)),
			feature(point(13.70981, 48.00664)),
			feature(point(13.70806, 48.00646)),
			feature(point(13.70629, 48.00641)),
			feature(point(13.70469, 48.00649)),
			feature(point(13.6909, 48.00826)),
			feature(point(13.68844, 48.0084)),
			feature(point(13.68556, 48.00814)),
			feature(point(13.67818, 48.00653)),
			feature(point(13.67626, 48.00637)),
			feature(point(13.67534, 48.00645)),
			feature(point(13.67429, 48.00667)),
			{
				type: 'Feature',
				properties: {
					type: 'stop',
					id: '8100507',
					name: 'Vöcklabruck Bahnhof',
					location: {
						type: 'location',
						id: '8100507',
						latitude: 48.010002,
						longitude: 13.663936,
					},
					products: {
						nationalExpress: true,
						national: false,
						interregional: true,
						regional: true,
						suburban: true,
						bus: false,
						ferry: false,
						subway: false,
						tram: false,
						onCall: false,
					},
				},
				geometry: point(13.66394, 48.01),
			},
			feature(point(13.66038, 48.01116)),
			feature(point(13.65788, 48.01184)),
			feature(point(13.65559, 48.01217)),
			feature(point(13.65329, 48.01217)),
			feature(point(13.65158, 48.01196)),
			feature(point(13.65037, 48.01171)),
			feature(point(13.63519, 48.00798)),
			feature(point(13.62166, 48.00468)),
			feature(point(13.61896, 48.00429)),
			feature(point(13.61685, 48.0042)),
			feature(point(13.61472, 48.00431)),
			feature(point(13.61264, 48.00458)),
			feature(point(13.59562, 48.00801)),
			feature(point(13.58416, 48.01033)),
			feature(point(13.58082, 48.01123)),
			feature(point(13.5788, 48.01196)),
			feature(point(13.57739, 48.01258)),
			feature(point(13.57082, 48.01567)),
			feature(point(13.56873, 48.01644)),
			feature(point(13.56616, 48.01721)),
			feature(point(13.5626, 48.01799)),
			feature(point(13.54903, 48.02032)),
			feature(point(13.51489, 48.02627)),
			feature(point(13.51204, 48.02671)),
			feature(point(13.50975, 48.02688)),
			feature(point(13.50814, 48.02683)),
			feature(point(13.50641, 48.02659)),
			feature(point(13.50494, 48.02621)),
			feature(point(13.50309, 48.02546)),
			feature(point(13.50163, 48.02456)),
			feature(point(13.50033, 48.02336)),
			feature(point(13.49947, 48.0221)),
			feature(point(13.49891, 48.0204)),
			feature(point(13.49854, 48.00832)),
			feature(point(13.49824, 48.00665)),
			feature(point(13.4977, 48.00518)),
			feature(point(13.49654, 48.00321)),
			feature(point(13.49525, 48.00175)),
			feature(point(13.49433, 48.00092)),
			feature(point(13.49226, 47.99944)),
			feature(point(13.49079, 47.99861)),
			{
				type: 'Feature',
				properties: {
					type: 'stop',
					id: '8100508',
					name: 'Vöcklamarkt Bahnhof',
					location: {
						type: 'location',
						id: '8100508',
						latitude: 47.99792,
						longitude: 13.489321,
					},
					products: {
						nationalExpress: false,
						national: false,
						interregional: false,
						regional: true,
						suburban: true,
						bus: false,
						ferry: false,
						subway: false,
						tram: false,
						onCall: false,
					},
				},
				geometry: point(13.48932, 47.99792),
			},
			feature(point(13.4877, 47.99737)),
			feature(point(13.48626, 47.997)),
			feature(point(13.48461, 47.99662)),
			feature(point(13.48257, 47.9963)),
			feature(point(13.46535, 47.99526)),
			feature(point(13.46351, 47.99496)),
			feature(point(13.46187, 47.99437)),
			feature(point(13.46039, 47.99349)),
			feature(point(13.45606, 47.98917)),
			feature(point(13.45553, 47.98874)),
			feature(point(13.45449, 47.98819)),
			feature(point(13.45303, 47.98775)),
			feature(point(13.44418, 47.986)),
			feature(point(13.43981, 47.98502)),
			feature(point(13.43257, 47.98307)),
			feature(point(13.41997, 47.97957)),
			feature(point(13.41717, 47.9792)),
			feature(point(13.41565, 47.97917)),
			feature(point(13.41421, 47.97928)),
			feature(point(13.41313, 47.97947)),
			feature(point(13.41163, 47.97991)),
			feature(point(13.40439, 47.98259)),
			feature(point(13.40306, 47.98316)),
			feature(point(13.40183, 47.98398)),
			feature(point(13.39971, 47.98613)),
			feature(point(13.39849, 47.98693)),
			feature(point(13.39767, 47.98731)),
			feature(point(13.39648, 47.98767)),
			feature(point(13.39527, 47.98789)),
			feature(point(13.39298, 47.98794)),
			feature(point(13.39145, 47.9877)),
			feature(point(13.38764, 47.98676)),
			feature(point(13.38624, 47.98635)),
			feature(point(13.38457, 47.98565)),
			feature(point(13.38314, 47.98483)),
			feature(point(13.38193, 47.98389)),
			feature(point(13.37901, 47.98066)),
			feature(point(13.37784, 47.97971)),
			feature(point(13.37681, 47.9792)),
			feature(point(13.37606, 47.97894)),
			feature(point(13.37489, 47.97869)),
			feature(point(13.37335, 47.9786)),
			feature(point(13.3716, 47.9788)),
			feature(point(13.37021, 47.97923)),
			feature(point(13.35596, 47.98656)),
			feature(point(13.35444, 47.98739)),
			feature(point(13.35372, 47.9879)),
			feature(point(13.35109, 47.99051)),
			feature(point(13.35041, 47.99105)),
			feature(point(13.34969, 47.99145)),
			feature(point(13.34876, 47.99181)),
			feature(point(13.34754, 47.99207)),
			feature(point(13.34661, 47.99214)),
			feature(point(13.34548, 47.9921)),
			feature(point(13.34467, 47.99197)),
			feature(point(13.34366, 47.99168)),
			feature(point(13.33266, 47.98683)),
			feature(point(13.33072, 47.98606)),
			feature(point(13.32035, 47.98277)),
			feature(point(13.31893, 47.98183)),
			feature(point(13.31815, 47.98086)),
			feature(point(13.31781, 47.97999)),
			feature(point(13.31699, 47.97646)),
			feature(point(13.31642, 47.97523)),
			feature(point(13.31574, 47.9742)),
			feature(point(13.31502, 47.97336)),
			feature(point(13.31397, 47.97238)),
			feature(point(13.31013, 47.96954)),
			feature(point(13.3084, 47.968)),
			feature(point(13.30712, 47.96625)),
			feature(point(13.30434, 47.96074)),
			feature(point(13.30328, 47.95974)),
			feature(point(13.30173, 47.95894)),
			feature(point(13.30058, 47.95861)),
			feature(point(13.29953, 47.95846)),
			feature(point(13.29842, 47.95842)),
			feature(point(13.29722, 47.95853)),
			feature(point(13.29, 47.96028)),
			feature(point(13.28781, 47.96097)),
			feature(point(13.28599, 47.96172)),
			feature(point(13.26444, 47.97205)),
			feature(point(13.26139, 47.97346)),
			feature(point(13.25842, 47.97437)),
			feature(point(13.25718, 47.97453)),
			feature(point(13.25583, 47.97459)),
			feature(point(13.2536, 47.97439)),
			feature(point(13.25122, 47.97378)),
			feature(point(13.24973, 47.9731)),
			feature(point(13.24069, 47.96764)),
			{
				type: 'Feature',
				properties: {
					type: 'stop',
					id: '8100020',
					name: 'Steindorf b.Straßwalchen Bahnhof',
					location: {
						type: 'location',
						id: '8100020',
						latitude: 47.966683,
						longitude: 13.239124,
					},
					products: {
						nationalExpress: false,
						national: false,
						interregional: false,
						regional: true,
						suburban: true,
						bus: false,
						ferry: false,
						subway: false,
						tram: false,
						onCall: false,
					},
				},
				geometry: point(13.23912, 47.96669),
			},
			feature(point(13.23454, 47.96389)),
			feature(point(13.23295, 47.96274)),
			feature(point(13.23067, 47.96059)),
			{
				type: 'Feature',
				properties: {
					type: 'stop',
					id: '8100134',
					name: 'Neumarkt-Köstendorf Bahnhof',
					location: {
						type: 'location',
						id: '8100134',
						latitude: 47.954512,
						longitude: 13.224714,
					},
					products: {
						nationalExpress: true,
						national: false,
						interregional: true,
						regional: true,
						suburban: true,
						bus: false,
						ferry: false,
						subway: false,
						tram: false,
						onCall: false,
					},
				},
				geometry: point(13.22471, 47.95451),
			},
			feature(point(13.22338, 47.95317)),
			feature(point(13.22247, 47.95247)),
			feature(point(13.22153, 47.952)),
			feature(point(13.22, 47.95152)),
			feature(point(13.21804, 47.95127)),
			feature(point(13.19579, 47.94924)),
			feature(point(13.18396, 47.94739)),
			feature(point(13.18223, 47.94695)),
			feature(point(13.18139, 47.9466)),
			feature(point(13.18034, 47.94601)),
			feature(point(13.1795, 47.94532)),
			feature(point(13.1789, 47.94463)),
			feature(point(13.17829, 47.94341)),
			feature(point(13.17792, 47.94147)),
			feature(point(13.1774, 47.93989)),
			feature(point(13.17668, 47.93845)),
			feature(point(13.17561, 47.93694)),
			feature(point(13.17383, 47.93513)),
			feature(point(13.16102, 47.92394)),
			feature(point(13.16042, 47.92312)),
			feature(point(13.16013, 47.92249)),
			feature(point(13.15941, 47.91947)),
			feature(point(13.1591, 47.91825)),
			feature(point(13.15866, 47.91738)),
			feature(point(13.15775, 47.91644)),
			feature(point(13.15691, 47.9159)),
			feature(point(13.1561, 47.91551)),
			feature(point(13.15505, 47.91519)),
			feature(point(13.1513, 47.91466)),
			feature(point(13.15016, 47.91439)),
			feature(point(13.14892, 47.91387)),
			feature(point(13.14449, 47.91161)),
			feature(point(13.14351, 47.91101)),
			feature(point(13.1428, 47.91032)),
			feature(point(13.14239, 47.90972)),
			feature(point(13.14211, 47.90903)),
			feature(point(13.14162, 47.907)),
			feature(point(13.14114, 47.90622)),
			feature(point(13.1405, 47.90555)),
			feature(point(13.13773, 47.90332)),
			feature(point(13.13571, 47.90197)),
			feature(point(13.13019, 47.89944)),
			feature(point(13.12341, 47.8964)),
			feature(point(13.12187, 47.89526)),
			feature(point(13.12084, 47.89391)),
			feature(point(13.12031, 47.89235)),
			feature(point(13.11853, 47.88271)),
			feature(point(13.11849, 47.8813)),
			feature(point(13.1189, 47.87743)),
			feature(point(13.11883, 47.87625)),
			feature(point(13.11854, 47.87538)),
			feature(point(13.11813, 47.87464)),
			feature(point(13.11737, 47.87377)),
			feature(point(13.11644, 47.87304)),
			feature(point(13.1135, 47.87148)),
			feature(point(13.11279, 47.87098)),
			feature(point(13.11232, 47.87045)),
			feature(point(13.11139, 47.86881)),
			feature(point(13.11082, 47.86808)),
			feature(point(13.11007, 47.86745)),
			feature(point(13.1092, 47.867)),
			feature(point(13.10756, 47.8665)),
			feature(point(13.10547, 47.8662)),
			feature(point(13.10087, 47.86627)),
			feature(point(13.10003, 47.8662)),
			feature(point(13.09881, 47.86593)),
			feature(point(13.09757, 47.86535)),
			feature(point(13.09664, 47.86453)),
			feature(point(13.09619, 47.86384)),
			feature(point(13.09549, 47.86109)),
			feature(point(13.09496, 47.86005)),
			feature(point(13.09441, 47.85944)),
			feature(point(13.09359, 47.8588)),
			feature(point(13.09198, 47.85799)),
			feature(point(13.09028, 47.85746)),
			feature(point(13.08741, 47.85694)),
			feature(point(13.08598, 47.85686)),
			feature(point(13.08196, 47.857)),
			feature(point(13.07881, 47.8565)),
			feature(point(13.07772, 47.85611)),
			feature(point(13.07708, 47.85576)),
			feature(point(13.07423, 47.8537)),
			feature(point(13.07291, 47.85314)),
			feature(point(13.07184, 47.8529)),
			feature(point(13.07102, 47.85283)),
			feature(point(13.06993, 47.85288)),
			feature(point(13.06601, 47.85357)),
			feature(point(13.06477, 47.85356)),
			feature(point(13.06397, 47.85343)),
			feature(point(13.06264, 47.85298)),
			feature(point(13.05752, 47.85003)),
			feature(point(13.05655, 47.84912)),
			feature(point(13.05607, 47.84809)),
			feature(point(13.05604, 47.84721)),
			feature(point(13.05648, 47.84618)),
			feature(point(13.05781, 47.84479)),
			feature(point(13.05921, 47.84373)),
			feature(point(13.06046, 47.84299)),
			feature(point(13.06293, 47.84176)),
			feature(point(13.06395, 47.84109)),
			feature(point(13.06466, 47.84035)),
			feature(point(13.06522, 47.83929)),
			feature(point(13.06639, 47.83604)),
			feature(point(13.06643, 47.83482)),
			feature(point(13.06612, 47.83406)),
			feature(point(13.06552, 47.83336)),
			feature(point(13.06487, 47.83285)),
			feature(point(13.06321, 47.83196)),
			feature(point(13.05753, 47.82904)),
			feature(point(13.05593, 47.82788)),
			feature(point(13.05495, 47.82689)),
			feature(point(13.05248, 47.82332)),
			feature(point(13.05069, 47.82119)),
			feature(point(13.04872, 47.81824)),
			feature(point(13.04627, 47.81381)),
			feature(point(13.0456, 47.81285), salzburgHbf),
		],
	},
};

export {
	oebbTrip,
};
